##  Introduction to MCP
The Model Context Protocol (MCP) is an emerging open standard that defines how AI applications can discover and interact with tools, such as APIs or functions, by receiving structured context. Instead of merely connecting systems, MCP helps AI tools understand available capabilities, how to use them, and the data they operate on.
MCP enables AI agents to securely and consistently connect to external data, such as enterprise architecture data in SAP LeanIX, which is presented as tools. These agents can understand and interact with external data, enabling developers to build their own AI-driven solutions or workflows.
For comprehensive details on MCP, refer to the MCP specification.
![Diagram showing MCP server connecting AI clients to SAP LeanIX data and APIs.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio525a7a61eb1e46ce91624ac5027d6e41_LowRes.png)
MCP Server
